.. automodule:: flask_registry

.. automodule:: flask_registry.registries.modulediscovery

.. automodule:: flask_registry.registries.appdiscovery

.. automodule:: flask_registry.registries.pkgresources

.. automodule:: flask_registry.registries